QCommandLineOption

Struct QCommandLineOption 

pub struct QCommandLineOption { /* private fields */ }
The QCommandLineOption class defines a possible command-line option.

Qt Documentation: QCommandLineOption

Implementations

Source

impl QCommandLineOption

pub fn default_values(&self) -> QStringList

Returns the default values set for this option.

pub fn description(&self) -> QString

Returns the description set for this option.

pub fn names(&self) -> QStringList

Returns the names set for this option.

pub fn set_default_value(&mut self, default_value: &QString)

Sets the default value used for this option to default_value.

The default value is used if the user of the application does not specify the option on the command line.

If default_value is empty, the option has no default values.

pub fn set_default_values(&mut self, default_values: &QStringList)

Sets the list of default values used for this option to default_values.

The default values are used if the user of the application does not specify the option on the command line.

pub fn set_description(&mut self, description: &QString)

Sets the description used for this option to description. It is customary to add a “.” at the end of the description.

The description is used by QCommandLineParser::showHelp().

pub fn set_value_name(&mut self, value_name: &QString)

Sets the name of the expected value, for the documentation, to value_name.

Options without a value assigned have a boolean-like behavior: either the user specifies –option or they don’t.

Options with a value assigned need to set a name for the expected value, for the documentation of the option in the help output. An option with names o and output, and a value name of file will appear as -o, --output <file>.

Call QCommandLineParser::value if you expect the option to be present only once, and QCommandLineParser::values if you expect that option to be present multiple times.

pub fn value_name(&self) -> QString

Returns the name of the expected value.