QEventLoopProcessEventsFlag

Struct QEventLoopProcessEventsFlag 

#[repr(transparent)]
pub struct QEventLoopProcessEventsFlag { pub repr: i32, }
This enum controls the types of events processed by QEventLoop::process_events.

Fields

repr: i32

Implementations

Source

impl QEventLoopProcessEventsFlag

pub const AllEvents: Self

All events. Note that QEvent::DeferredDelete events are processed specially. See QObject::deleteLater() for more details.

pub const ExcludeUserInputEvents: Self

Do not process user input events, such as QEvent::MouseButtonPress and QEvent::KeyPress. Note that the events are not discarded; they will be delivered the next time QEventLoop::process_events is called without this flag.

pub const ExcludeSocketNotifiers: Self

Do not process socket notifier events. Note that the events are not discarded; they will be delivered the next time QEventLoop::process_events is called without this flag.

pub const WaitForMoreEvents: Self

Wait for events if no pending events are available.