#[repr(transparent)]pub struct QEventLoopProcessEventsFlag {
pub repr: i32,
}Expand description
This enum controls the types of events processed by QEventLoop::process_events.
Fields
repr: i32Implementations
Sourceimpl QEventLoopProcessEventsFlag
impl QEventLoopProcessEventsFlag
Sourcepub const AllEvents: Self
pub const AllEvents: Self
All events. Note that QEvent::DeferredDelete events are processed specially. See QObject::deleteLater() for more details.
Sourcepub const ExcludeUserInputEvents: Self
pub const ExcludeUserInputEvents: Self
Do not process user input events, such as QEvent::MouseButtonPress and QEvent::KeyPress. Note that the events are not discarded; they will be delivered the next time QEventLoop::process_events is called without this flag.
Sourcepub const ExcludeSocketNotifiers: Self
pub const ExcludeSocketNotifiers: Self
Do not process socket notifier events. Note that the events are not discarded; they will be delivered the next time QEventLoop::process_events is called without this flag.
Sourcepub const WaitForMoreEvents: Self
pub const WaitForMoreEvents: Self
Wait for events if no pending events are available.